### TODO

In addition to the todo in the code

### Asap
* **[DOC]** give more details as to the pendent drop method and the methods used here
* **[DOC]** Explain explicitely how to use the GUI app
* **[GUI]** actualize autothreshold not when ROI moved but when ROI let go (sigRegionChangeFinished)
* **[GUI]** replace density contrast by gravity + density difference

### Bonus
* **[GUI]** green isoline for main contour, yellow for other lines
*  calculate and output information that helps assessing the reliability of the measurement
* **[TST]** add tests on contour detection, on parameters estimation...

* (Bond or Worthington ?) number (ratio of weight to maximum capillary retaining force), indicates how far we are from break-off (thus how much the shape is influenced by gravity)

* error bars from Hessian matrix around optimum parameter set

* more precise/informative display of parameters